@@ -15,7 +15,7 @@ f2 = factor(fa, levels = fa)
 circos.initialize(factors = f2, xlim = c(0, 1))
 circos.trackPlotRegion(ylim = c(0, 1))
 circos.info(plot = TRUE)
-text(0, 0, "factor(fa,\nlevels = fa)", adj = c(0.5, 0.5), cex = 1.3)
+text(0, 0, "factor(fa, levels = fa)", adj = c(0.5, 0.5), cex = 1.3)
 circos.clear()
 
 par(op)
